--- openflow-2012-09-26.h	2015-07-23 09:54:17.788479388 -0700
+++ openflow-2014-04-21.h	2015-07-23 09:54:17.796479388 -0700
@@ -85,6 +85,8 @@
     OFPP_MAX        = 0xffffff00,
 
     /* Reserved OpenFlow Port (fake output "ports"). */
+    OFPP_UNSET      = 0xfffffff7,  /* Output port not set in action-set.
+                                      used only in OXM_OF_ACTSET_OUTPUT. */
     OFPP_IN_PORT    = 0xfffffff8,  /* Send the packet out the input port.  This
                                       reserved port must be explicitly used
                                       in order to send back out of the input
@@ -1171,7 +1173,7 @@
  * Metadata representing the forwarding decision in the action set.
  * If the action set contains an output action, this field equals
  * the output port.
  * Else, the field equals its initial value, OFPP_TABLE.
  *
  * Prereqs: None.
  *
@@ -1171,7 +1173,7 @@
  * If the action set contains an output action, this field equals
  * the output port.
- * Else, the field equals its initial value, OFPP_TABLE.
+ * Else, the field equals its initial value, OFPP_UNSET.
  *
  * Prereqs: None.
